@@ -41,9 +41,9 @@
 #include <QFileDialog>
 
 ThemeEditorPage::ThemeEditorPage(const QString &projectDir, const QString &themeName, QWidget *parent)
-    : QWidget(parent),
-      mThemeSession(new GrantleeThemeEditor::ThemeSession(projectDir, QStringLiteral("headerthemeeditor"))),
-      mChanged(false)
+    : QWidget(parent)
+    , mThemeSession(new GrantleeThemeEditor::ThemeSession(projectDir, QStringLiteral("headerthemeeditor")))
+    , mChanged(false)
 {
     QHBoxLayout *lay = new QHBoxLayout;
     mTabWidget = new GrantleeThemeEditor::ThemeEditorTabWidget;
@@ -152,7 +152,7 @@ void ThemeEditorPage::installTheme(const QString &themePath)
     }
     const QString newPath = themePath + QDir::separator() + mDesktopPage->themeName();
     mEditorPage->installTheme(newPath);
-    Q_FOREACH (EditorPage *page, mExtraPage) {
+    for (EditorPage *page : qAsConst(mExtraPage)) {
         page->installTheme(newPath);
     }
     mDesktopPage->installTheme(newPath);
@@ -174,7 +174,7 @@ void ThemeEditorPage::uploadTheme()
         lst << previewFileName;
         mEditorPage->preview()->createScreenShot(lst);
 
-        const bool fileAdded  = zip->addLocalFile(previewFileName, themename + QLatin1Char('/') + QLatin1String("theme_preview.png"));
+        const bool fileAdded = zip->addLocalFile(previewFileName, themename + QLatin1Char('/') + QLatin1String("theme_preview.png"));
         if (!fileAdded) {
             KMessageBox::error(this, i18n("We cannot add preview file in zip file"), i18n("Failed to add file."));
             delete zip;
@@ -203,7 +203,7 @@ void ThemeEditorPage::createZip(const QString &themeName, KZip *zip)
 {
     mEditorPage->createZip(themeName, zip);
 
-    Q_FOREACH (EditorPage *page, mExtraPage) {
+    for (EditorPage *page : qAsConst(mExtraPage)) {
         page->createZip(themeName, zip);
     }
     mDesktopPage->createZip(themeName, zip);
@@ -238,7 +238,7 @@ void ThemeEditorPage::storeTheme(const QString &directory)
     const QString themeDirectory = directory.isEmpty() ? projectDirectory() : directory;
     mEditorPage->saveTheme(themeDirectory);
 
-    Q_FOREACH (EditorPage *page, mExtraPage) {
+    for (EditorPage *page : qAsConst(mExtraPage)) {
         page->saveTheme(themeDirectory);
     }
     mDesktopPage->saveTheme(themeDirectory);
@@ -275,7 +275,7 @@ void ThemeEditorPage::loadTheme(const QString &filename)
         mEditorPage->preview()->setThemePath(mThemeSession->projectDirectory(), mThemeSession->mainPageFileName());
 
         const QStringList lstExtraPages = mThemeSession->extraPages();
-        Q_FOREACH (const QString &page, lstExtraPages) {
+        for (const QString &page : lstExtraPages) {
             EditorPage *extraPage = createExtraPage(page);
             extraPage->loadTheme(mThemeSession->projectDirectory() + QDir::separator() + page);
         }
@@ -298,4 +298,3 @@ void ThemeEditorPage::saveThemeAs(const QString &directory)
 {
     storeTheme(directory);
 }
-
