@@ -37,10 +37,9 @@ class GrantleeThemeEditor::ManageThemesPrivate
 {
 public:
     ManageThemesPrivate()
-        : mListThemes(nullptr),
-          mDeleteTheme(nullptr)
+        : mListThemes(nullptr)
+        , mDeleteTheme(nullptr)
     {
-
     }
 
     QString mLocalDirectory;
@@ -49,14 +48,14 @@ public:
 };
 
 ManageThemes::ManageThemes(const QString &relativeThemePath, QWidget *parent)
-    : QDialog(parent),
-      d(new GrantleeThemeEditor::ManageThemesPrivate)
+    : QDialog(parent)
+    , d(new GrantleeThemeEditor::ManageThemesPrivate)
 {
     d->mLocalDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + relativeThemePath;
     setWindowTitle(i18n("Manage Theme"));
     QWidget *w = new QWidget;
 
-    QVBoxLayout *lay = new QVBoxLayout;
+    QVBoxLayout *lay = new QVBoxLayout(w);
     lay->setMargin(0);
 
     QLabel *lab = new QLabel(i18n("Local themes:"));
@@ -72,8 +71,6 @@ ManageThemes::ManageThemes(const QString &relativeThemePath, QWidget *parent)
     d->mDeleteTheme->setEnabled(false);
     lay->addWidget(d->mDeleteTheme);
 
-    w->setLayout(lay);
-
     initialize();
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -146,4 +143,3 @@ void ManageThemes::slotItemSelectionChanged()
 {
     d->mDeleteTheme->setEnabled(!d->mListThemes->selectedItems().isEmpty());
 }
-
